@@ -5,7 +5,7 @@
 from ._arraykit import __version__
 from ._arraykit import ArrayGO as ArrayGO
 from ._arraykit import BlockIndex as BlockIndex
-from ._arraykit import ErrorInitBlocks as ErrorInitBlocks
+from ._arraykit import ErrorInitTypeBlocks as ErrorInitTypeBlocks
 
 from ._arraykit import immutable_filter as immutable_filter
 from ._arraykit import mloc as mloc
