@@ -351,6 +351,9 @@ class TestUnit(unittest.TestCase):
         ts = pd.Timestamp('nat')
         self.assertTrue(isna_element(ts))
 
+        s1 = pd.Series((0,))
+        self.assertFalse(isna_element(s1))
+
 
     def test_isna_element_e(self) -> None:
         from types import SimpleNamespace
@@ -358,6 +361,7 @@ class TestUnit(unittest.TestCase):
         sn.to_numpy = None
         self.assertFalse(isna_element(sn))
 
+
     #---------------------------------------------------------------------------
 
     def test_dtype_from_element_core_dtypes(self) -> None:
